/*
   Reflex Tester:
   Start game with the button.
   Warning beeps will let the player know that it is about to begin.
   After random delay, speaker beeps once at a different tone to indicate start.
   Objective is to react as quickly as possible with button2.
   LEDs will display the player score.
*/

//array for LEDs
const int led[] = {13, 3, 4, 5,  6, 7, 8, 9};
//integers for buttons
const int button1 = 15;
const int button2 = 16;
//integer for speaker
const int speaker = 2;

//integers to track if buttons have been pressed
int pressed1 = 0;
int pressed2 = 0;

//integer for timer
int timer = 0;
//integer for the random delay at start of the game
int startTime = 0;


void setup() {

  //set LEDs to output
  for (int x = 0; x < 8; x++) {
    pinMode(led[x], OUTPUT);
  }

  //set buttons to input
  pinMode(button1, INPUT);
  pinMode(button2, INPUT);
}

void loop() {

  //determine random delay time
  startTime = random(500, 3000);

  //wait for button1 to be pressed
  while (!pressed1) {
    pressed1 = digitalRead(button1);
  }

  //reset button1
  pressed1 = 0;

  //play starting beeps
  startSequence();
  //reset timer
  timer = 0;

  while ((timer < startTime) && (!pressed2)) {

    //check button2
    pressed2 = digitalRead(button2);
    timer++;
    delay(1);
  }

  //if player pressed button early
  if (pressed2) {

    //reset button2
    pressed2 = 0;
    //player faults
    lose();
  }

  //no fault, continue game
  else {

    //reaction beep
    tone(speaker, 800);
    delay(100);
    noTone(speaker);

    //use player score to determine reaction time
    playerScore();
  }

  //reset start time
  startTime = 0;
}

//funtion to return player score
void playerScore() {

  //create local variable for tracking players reaction time
  int count = 0;

  //delay for "human element"
  delay(25);

  //wait for button to be pressed as long as count < 800
  while ((!pressed2) && (count < 225)) {

    //check button2
    pressed2 = digitalRead(button2);
    //increase count
    count++;
    //wait 1ms to increase count again
    delay(1);
  }

  //reset button2
  pressed2 = 0;
  //scale count by factor of 4
  count = 4 * count;

  if (count >= 900) {
    //lose sequence
    lose();
  }

  else {
    //win sequence
    win(count);
  }

  //reset count
  count = 0;
}

//losing sequence for no reaction
void lose() {

  //blink bottom LED and make low-tone
  for (int x = 0; x < 5; x++) {

    tone(speaker, 200);
    digitalWrite(led[0], HIGH);
    delay(200);

    noTone(speaker);
    digitalWrite(led[0], LOW);
    delay(200);
  }
}

//win sequence and score display
void win(int score) {

  //create local variable for win freq
  int freq = (900 - score) * 2;

  //scale down by 100
  score = score / 100;

  //flash 5 times
  for (int count = 0; count < 5; count++) {

    //display score on LEDs
    for (int x = 0; x < (8 - score); x++) {
      digitalWrite(led[x], HIGH);
      tone(speaker, freq);
    }

    delay(200);

    //turn LEDs off
    for (int x = 0; x < (8 - score); x++) {
      digitalWrite(led[x], LOW);
      noTone(speaker);
    }

    delay(200);
  }
}

//function for starting beeps
void startSequence() {

  //beep 3 times
  for (int x = 0; x < 3; x++) {

    //on for 100ms
    tone(speaker, 800);
    delay(100);

    //off for 500ms
    noTone(speaker);
    delay(500);
  }

  //starting beep
  tone(speaker, 1600);
  delay(100);
  noTone(speaker);
}
